@@ -1,16 +1,18 @@
 #!/usr/bin/env python
 # -*- coding: utf_8 -*-
 from .core_matcher.pattern_matcher import PatternMatcher
+from .core_matcher.choice_matcher import ChoiceMatcher
 from .core_sgrep.semantic_sgrep import SemanticGrep
 from .scanner import Scanner
 
 __title__ = 'libsast'
 __authors__ = 'Ajin Abraham'
 __copyright__ = 'Copyright 2020 Ajin Abraham, OpenSecurity'
-__version__ = '1.2.3'
+__version__ = '1.3.0'
 __version_info__ = tuple(int(i) for i in __version__.split('.'))
 __all__ = [
     'Scanner',
+    'ChoiceMatcher',
     'PatternMatcher',
     'SemanticGrep',
     '__title__',
